@@ -76,9 +76,9 @@ impl<T> Drop for QueueSender<T> {
     }
 }
 
-unsafe impl<T> Sync for QueueSender<T> {}
+unsafe impl<T: Send> Sync for QueueSender<T> {}
 
-unsafe impl<T> Send for QueueSender<T> {}
+unsafe impl<T: Send> Send for QueueSender<T> {}
 
 /// A `QueueReceiver` is used to pop previously
 /// pushed items from the queue.
@@ -181,7 +181,7 @@ impl<T> Drop for QueueReceiver<T> {
     }
 }
 
-unsafe impl<T> Send for QueueReceiver<T> {}
+unsafe impl<T: Send> Send for QueueReceiver<T> {}
 
 pub struct Queue;
 
